@@ -10,6 +10,9 @@
     ("set0" . 8709) ;; ∅ U+2205
     ("`<`" . 8842) ;; ⊊ U+228A
     ("`<=`" . 8838) ;; ⊆ U+2286
+    ("`*`" . ?×) ;; × U+00D7
+    ("\\in" . ?∈) ;; ∈ U+2208
+    ("\\notin" . ?∉) ;; ∉ U+2209
     ("^\\+" . ?⁺) ;; ⁺ U+207A
     ("^\\-" . ?⁻) ;; ⁻ U+207B
 ))))
